==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SecretLocalReferenceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SecretLocalReferenceBuilder extends io.fabric8.openshift.api.model.SecretLocalReferenceFluentImpl<io.fabric8.openshift.api.model.SecretLocalReferenceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SecretLocalReference,io.fabric8.openshift.api.model.SecretLocalReferenceBuilder>{
  public SecretLocalReferenceBuilder() {
    this(false);
  }
  public SecretLocalReferenceBuilder(java.lang.Boolean validationEnabled) {
    this(new SecretLocalReference(), validationEnabled);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SecretLocalReference(), validationEnabled);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent,io.fabric8.openshift.api.model.SecretLocalReference instance) {
    this(fluent, instance, false);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent,io.fabric8.openshift.api.model.SecretLocalReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReference instance) {
    this(instance,false);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SecretLocalReference build() {
    SecretLocalReference buildable = new SecretLocalReference(fluent.getName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretLocalReferenceBuilder that = (SecretLocalReferenceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/SecretLocalReferenceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SecretLocalReferenceBuilder extends io.fabric8.openshift.api.model.SecretLocalReferenceFluentImpl<io.fabric8.openshift.api.model.SecretLocalReferenceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SecretLocalReference,io.fabric8.openshift.api.model.SecretLocalReferenceBuilder>{
  public SecretLocalReferenceBuilder() {
    this(false);
  }
  public SecretLocalReferenceBuilder(java.lang.Boolean validationEnabled) {
    this(new SecretLocalReference(), validationEnabled);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SecretLocalReference(), validationEnabled);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent,io.fabric8.openshift.api.model.SecretLocalReference instance) {
    this(fluent, instance, false);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent,io.fabric8.openshift.api.model.SecretLocalReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReference instance) {
    this(instance,false);
  }
  public SecretLocalReferenceBuilder(io.fabric8.openshift.api.model.SecretLocalReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SecretLocalReferenceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SecretLocalReference build() {
    SecretLocalReference buildable = new SecretLocalReference(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretLocalReferenceBuilder that = (SecretLocalReferenceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
